@@ -1,6 +1,6 @@
 from typing import Optional
 from pydantic import BaseModel
-from src.interfaces.main import Error
+from connector_vk_private_lib.src.interfaces.main import Error
 
 
 class ResponseGetGroups200(BaseModel):
