@@ -2,8 +2,8 @@ from typing import Optional
 
 from pydantic import BaseModel
 
-from interfaces.attachments import Attachment
-from interfaces.main import Repost, Error
+from connector_vk_private_lib.src.interfaces.attachments import Attachment
+from connector_vk_private_lib.src.interfaces.main import Repost, Error
 
 
 class GetWallItemComment(BaseModel):
